@@ -1,7 +1,6 @@
 /* Target-dependent code for GNU/Linux x86-64.
 
-   Copyright (C) 2001-2022 Free Software Foundation, Inc.
-   Copyright (C) 2013-2021 Intel Corporation
+   Copyright (C) 2001-2023 Free Software Foundation, Inc.
    Contributed by Jiri Smid, SuSE Labs.
 
    This file is part of GDB.
@@ -98,7 +97,6 @@ int amd64_linux_gregset_reg_offset[] =
   -1, -1, -1, -1, -1, -1, -1, -1,
   -1, -1, -1, -1, -1, -1, -1, -1,
   -1,				/* PKEYS register pkru  */
-  -1, -1,			/* CET user mode registers CET_U, PL3_SSP.  */
   -1,				/* TILECFG register (AMX).  */
   -1,			 	/* TILEDATA registers tmm0 ... tmm7 (AMX).  */
 
@@ -137,7 +135,7 @@ static const gdb_byte amd64_x32_linux_sigtramp_code[] =
    the routine.  Otherwise, return 0.  */
 
 static CORE_ADDR
-amd64_linux_sigtramp_start (struct frame_info *this_frame)
+amd64_linux_sigtramp_start (frame_info_ptr this_frame)
 {
   struct gdbarch *gdbarch;
   const gdb_byte *sigtramp_code;
@@ -179,7 +177,7 @@ amd64_linux_sigtramp_start (struct frame_info *this_frame)
    routine.  */
 
 static int
-amd64_linux_sigtramp_p (struct frame_info *this_frame)
+amd64_linux_sigtramp_p (frame_info_ptr this_frame)
 {
   CORE_ADDR pc = get_frame_pc (this_frame);
   const char *name;
@@ -205,7 +203,7 @@ amd64_linux_sigtramp_p (struct frame_info *this_frame)
    address of the associated sigcontext structure.  */
 
 static CORE_ADDR
-amd64_linux_sigcontext_addr (struct frame_info *this_frame)
+amd64_linux_sigcontext_addr (frame_info_ptr this_frame)
 {
   struct gdbarch *gdbarch = get_frame_arch (this_frame);
   enum bfd_endian byte_order = gdbarch_byte_order (gdbarch);
@@ -283,7 +281,7 @@ static int amd64_linux_sc_reg_offset[] =
 
 static int
 amd64_linux_register_reggroup_p (struct gdbarch *gdbarch, int regnum,
-				 struct reggroup *group)
+				 const struct reggroup *group)
 { 
   if (regnum == AMD64_LINUX_ORIG_RAX_REGNUM
       || regnum == AMD64_FSBASE_REGNUM
@@ -320,7 +318,7 @@ amd64_linux_write_pc (struct regcache *regcache, CORE_ADDR pc)
   /* If we have interrupted a restart-able AMX instruction we should clear
      start_row.  Any instructions we will now run should start at row 0.  */
   i386_gdbarch_tdep *tdep
-    = (i386_gdbarch_tdep *) gdbarch_tdep (regcache->arch ());
+    = gdbarch_tdep<i386_gdbarch_tdep> (regcache->arch ());
   if (tdep != nullptr && tdep->tilecfg_raw_regnum != -1)
     {
       gdb_byte tilecfg_buf[register_size (regcache->arch (),
@@ -488,6 +486,12 @@ amd64_canonicalize_syscall (enum amd64_syscall syscall_number)
   case amd64_x32_sys_pipe:
     return gdb_sys_pipe;
 
+  case amd64_sys_pipe2:
+    return gdb_sys_pipe2;
+
+  case amd64_sys_getrandom:
+    return gdb_sys_getrandom;
+
   case amd64_sys_select:
   case amd64_x32_sys_select:
     return gdb_sys_select;
@@ -1524,10 +1528,10 @@ amd64_linux_syscall_record_common (struct regcache *regcache,
 
   if (syscall_gdb == gdb_sys_no_syscall)
     {
-      fprintf_unfiltered (gdb_stderr,
-			  _("Process record and replay target doesn't "
-			    "support syscall number %s\n"), 
-			  pulongest (syscall_native));
+      gdb_printf (gdb_stderr,
+		  _("Process record and replay target doesn't "
+		    "support syscall number %s\n"), 
+		  pulongest (syscall_native));
       return -1;
     }
   else
@@ -1602,14 +1606,12 @@ amd64_linux_record_signal (struct gdbarch *gdbarch,
 }
 
 const target_desc *
-amd64_linux_read_description (uint64_t xcr0_features_bit, bool is_x32,
-			      bool shstk_enabled, bool ibt_enabled)
+amd64_linux_read_description (uint64_t xcr0_features_bit, bool is_x32)
 {
   static target_desc *amd64_linux_tdescs \
-    [2/*AVX*/][2/*MPX*/][2/*AVX512*/][2/*PKRU*/][2/*CET_U*/][2/*PL3_SSP*/]\
-    [2/*AMX*/] = {};
-  static target_desc *x32_linux_tdescs[2/*AVX*/][2/*AVX512*/][2/*PKRU*/]\
-    [2/*CET_U*/][2/*PL3_SSP*/][2/*AMX*/] = {};
+    [2/*AVX*/][2/*MPX*/][2/*AVX512*/][2/*PKRU*/][2/*AMX*/] = {};
+  static target_desc *x32_linux_tdescs \
+    [2/*AVX*/][2/*AVX512*/][2/*PKRU*/][2/*AMX*/] = {};
 
   target_desc **tdesc;
 
@@ -1618,8 +1620,6 @@ amd64_linux_read_description (uint64_t xcr0_features_bit, bool is_x32,
       tdesc = &x32_linux_tdescs[(xcr0_features_bit & X86_XSTATE_AVX) ? 1 : 0 ]
 	[(xcr0_features_bit & X86_XSTATE_AVX512) ? 1 : 0]
 	[(xcr0_features_bit & X86_XSTATE_PKRU) ? 1 : 0]
-	[(shstk_enabled || ibt_enabled) ? 1 : 0]
-	[shstk_enabled ? 1 : 0]
 	[(xcr0_features_bit & X86_XSTATE_AMX) ? 1 : 0];
     }
   else
@@ -1628,14 +1628,12 @@ amd64_linux_read_description (uint64_t xcr0_features_bit, bool is_x32,
 	[(xcr0_features_bit & X86_XSTATE_MPX) ? 1 : 0]
 	[(xcr0_features_bit & X86_XSTATE_AVX512) ? 1 : 0]
 	[(xcr0_features_bit & X86_XSTATE_PKRU) ? 1 : 0]
-	[(shstk_enabled || ibt_enabled) ? 1 : 0]
-	[shstk_enabled ? 1 : 0]
 	[(xcr0_features_bit & X86_XSTATE_AMX) ? 1 : 0];
     }
 
   if (*tdesc == NULL)
-    *tdesc = amd64_create_target_description (xcr0_features_bit, is_x32, true,
-					      true, shstk_enabled, ibt_enabled);
+    *tdesc = amd64_create_target_description (xcr0_features_bit, is_x32,
+					      true, true);
 
   return *tdesc;
 }
@@ -1649,11 +1647,9 @@ amd64_linux_core_read_description (struct gdbarch *gdbarch,
 {
   /* Linux/x86-64.  */
   uint64_t xcr0 = i386_linux_core_read_xcr0 (abfd);
-  bool cet_enabled = i386_linux_core_read_cet_state_p (abfd);
 
   return amd64_linux_read_description (xcr0 & X86_XSTATE_ALL_MASK,
-				       gdbarch_ptr_bit (gdbarch) == 32,
-				       cet_enabled, cet_enabled);
+				       gdbarch_ptr_bit (gdbarch) == 32);
 }
 
 /* Similar to amd64_supply_fpregset, but use XSAVE extended state.  */
@@ -1691,15 +1687,12 @@ amd64_linux_iterate_over_regset_sections (struct gdbarch *gdbarch,
 					  void *cb_data,
 					  const struct regcache *regcache)
 {
-  i386_gdbarch_tdep *tdep = (i386_gdbarch_tdep *) gdbarch_tdep (gdbarch);
+  i386_gdbarch_tdep *tdep = gdbarch_tdep<i386_gdbarch_tdep> (gdbarch);
 
   cb (".reg", 27 * 8, 27 * 8, &i386_gregset, NULL, cb_data);
   cb (".reg2", 512, 512, &amd64_fpregset, NULL, cb_data);
   cb (".reg-xstate", X86_XSTATE_SIZE (tdep->xcr0), X86_XSTATE_SIZE (tdep->xcr0),
       &amd64_linux_xstateregset, "XSAVE extended state", cb_data);
-
-  if (tdep->cet_msr_regnum > 0 || tdep->ssp_regnum > 0)
-    cb (".cet-state", 16, 16, &i386_linux_cet_regset, "CET state", cb_data);
 }
 
 /* The instruction sequences used in x86_64 machines for a
@@ -1831,7 +1824,7 @@ static void
 amd64_linux_init_abi_common(struct gdbarch_info info, struct gdbarch *gdbarch,
 			    int num_disp_step_buffers)
 {
-  i386_gdbarch_tdep *tdep = (i386_gdbarch_tdep *) gdbarch_tdep (gdbarch);
+  i386_gdbarch_tdep *tdep = gdbarch_tdep<i386_gdbarch_tdep> (gdbarch);
 
   linux_init_abi (info, gdbarch, num_disp_step_buffers);
 
@@ -1884,7 +1877,7 @@ amd64_linux_init_abi_common(struct gdbarch_info info, struct gdbarch *gdbarch,
 static void
 amd64_linux_init_abi (struct gdbarch_info info, struct gdbarch *gdbarch)
 {
-  i386_gdbarch_tdep *tdep = (i386_gdbarch_tdep *) gdbarch_tdep (gdbarch);
+  i386_gdbarch_tdep *tdep = gdbarch_tdep<i386_gdbarch_tdep> (gdbarch);
   struct tdesc_arch_data *tdesc_data = info.tdesc_data;
   const struct tdesc_feature *feature;
   int valid_p;
@@ -2098,7 +2091,7 @@ amd64_linux_init_abi (struct gdbarch_info info, struct gdbarch *gdbarch)
 static void
 amd64_x32_linux_init_abi (struct gdbarch_info info, struct gdbarch *gdbarch)
 {
-  i386_gdbarch_tdep *tdep = (i386_gdbarch_tdep *) gdbarch_tdep (gdbarch);
+  i386_gdbarch_tdep *tdep = gdbarch_tdep<i386_gdbarch_tdep> (gdbarch);
   struct tdesc_arch_data *tdesc_data = info.tdesc_data;
   const struct tdesc_feature *feature;
   int valid_p;
