@@ -27,7 +27,7 @@ bool
 get_inst_bit (const gdb_byte inst[], int pos)
 {
   if (pos < 0 || (MAX_INST_LENGTH * 8) <= pos)
-    internal_error (__FILE__, __LINE__, _("bad bit offset: %d"), pos);
+    internal_error (_("bad bit offset: %d"), pos);
 
   const int idx = pos >> 3;
   const int off = pos & 7;
@@ -43,7 +43,7 @@ bool
 set_inst_bit (gdb_byte inst[], int pos)
 {
   if (pos < 0 || (MAX_INST_LENGTH * 8) <= pos)
-    internal_error (__FILE__, __LINE__, _("bad bit offset: %d"), pos);
+    internal_error (_("bad bit offset: %d"), pos);
 
   const int idx = pos >> 3;
   const int off = pos & 7;
@@ -62,7 +62,7 @@ bool
 clear_inst_bit (gdb_byte inst[], int pos)
 {
   if (pos < 0 || (MAX_INST_LENGTH * 8) <= pos)
-    internal_error (__FILE__, __LINE__, _("bad bit offset: %d"), pos);
+    internal_error (_("bad bit offset: %d"), pos);
 
   const int idx = pos >> 3;
   const int off = pos & 7;
