@@ -1,6 +1,5 @@
 /* Remote utility routines for the remote server for GDB.
-   Copyright (C) 1986-2022 Free Software Foundation, Inc.
-   Copyright (C) 2020-2021 Intel Corporation
+   Copyright (C) 1986-2023 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -297,8 +296,7 @@ remote_prepare (const char *name)
       ((struct sockaddr_in6 *) iter->ai_addr)->sin6_addr = in6addr_any;
       break;
     default:
-      internal_error (__FILE__, __LINE__,
-		      _("Invalid 'ai_family' %d\n"), iter->ai_family);
+      internal_error (_("Invalid 'ai_family' %d\n"), iter->ai_family);
     }
 
   if (bind (listen_desc, iter->ai_addr, iter->ai_addrlen) != 0)
@@ -1060,8 +1058,9 @@ void
 prepare_resume_reply (char *buf, ptid_t ptid, const target_waitstatus &status)
 {
   client_state &cs = get_client_state ();
-  threads_debug_printf ("Writing resume reply for %s:%d",
-			target_pid_to_str (ptid).c_str (), status.kind ());
+  threads_debug_printf ("Writing resume reply for %s: %s",
+			target_pid_to_str (ptid).c_str (),
+			target_waitkind_str (status.kind ()));
 
   switch (status.kind ())
     {
@@ -1076,6 +1075,7 @@ prepare_resume_reply (char *buf, ptid_t ptid, const target_waitstatus &status)
       {
 	const char **regp;
 	struct regcache *regcache;
+	char *buf_start = buf;
 
 	if ((status.kind () == TARGET_WAITKIND_FORKED && cs.report_fork_events)
 	    || (status.kind () == TARGET_WAITKIND_VFORKED
@@ -1146,11 +1146,11 @@ prepare_resume_reply (char *buf, ptid_t ptid, const target_waitstatus &status)
 	       An 'S' stop packet always looks like 'Sxx', so all we do
 	       here is convert the buffer from a T packet to an S packet
 	       and the avoid adding any extra content by breaking out.  */
-	    gdb_assert (*buf == 'T');
-	    gdb_assert (isxdigit (*(buf + 1)));
-	    gdb_assert (isxdigit (*(buf + 2)));
-	    *buf = 'S';
-	    *(buf + 3) = '\0';
+	    gdb_assert (buf_start[0] == 'T');
+	    gdb_assert (isxdigit (buf_start[1]));
+	    gdb_assert (isxdigit (buf_start[2]));
+	    buf_start[0] = 'S';
+	    buf_start[3] = '\0';
 	    break;
 	  }
 
@@ -1162,7 +1162,7 @@ prepare_resume_reply (char *buf, ptid_t ptid, const target_waitstatus &status)
 
 	regp = current_target_desc ()->expedite_regs;
 
-	regcache = get_thread_regcache (current_thread, 1);
+	regcache = get_thread_regcache (current_thread);
 
 	if (the_target->stopped_by_watchpoint ())
 	  {
@@ -1302,6 +1302,24 @@ prepare_resume_reply (char *buf, ptid_t ptid, const target_waitstatus &status)
 
 /* See remote-utils.h.  */
 
+void
+output_expedite_registers (char *buf)
+{
+  /* We are being asked to return only the expedite regs.  Do not
+     fetch the registers alltogether.  */
+  regcache *regcache = get_thread_regcache (current_thread, false);
+  const char **regp = current_target_desc ()->expedite_regs;
+
+  while (*regp)
+    {
+      buf = outreg (regcache, find_regno (regcache->tdesc, *regp), buf);
+      regp ++;
+    }
+  *buf = '\0';
+}
+
+/* See remote-utils.h.  */
+
 const char *
 decode_m_packet_params (const char *from, CORE_ADDR *mem_addr_ptr,
 			unsigned int *len_ptr, const char end_marker,
@@ -1684,4 +1702,46 @@ monitor_output (const char *msg)
   free (buf);
 }
 
+/* See remote-utils.h.  */
+
+void
+critical_error (int code, const char *format, ...)
+{
+  va_list arg;
+  va_start (arg, format);
+  char buf[400];
+  char *p = buf;
+  p += sprintf (p, "E%02X", code);
+  vsnprintf (p, 400 - (p - buf), format, arg);
+
+  /* Write packet only when the connection to GDB is ready.  */
+  if (gdb_connected () )
+    putpkt (buf);
+
+  verror (format, arg);
+  va_end (arg);
+}
+
+/* See remote-utils.h.  */
+
+void
+non_critical_error (const char *format, ...)
+{
+  va_list arg;
+  va_start (arg, format);
+  char buf[400];
+  buf[0] = 'E';
+  buf[1] = '0';
+  buf[2] = '1';
+  char *p = buf + 3;
+  vsnprintf (p, 400 - (p - buf), format, arg);
+
+  /* Write packet only when the connection to GDB is ready.  */
+  if (gdb_connected ())
+    putpkt (buf);
+
+  fprintf (stderr, "%s", &buf[3]);
+  va_end (arg);
+}
+
 #endif
